@@ -1,10 +1,7 @@
-//  types for store set on notebook re-run
-// TODO merge this type with ColumnProfileData below 
-/*eslint-disable*/
 export type IColTypeTuple = {
-    col_name: string;
-    col_type: string;
-    col_is_index: boolean;
+    colName: string;
+    colType: string;
+    colIsIndex: boolean;
 };
 
 export type Warning = {
@@ -25,7 +22,12 @@ export type IDFProfileWStateMap = {
 } | undefined;
 
 
-export type IDFProfileWState = IDFProfileData & IDFProfileState
+export type IDFProfileData = {
+    profile: ColumnProfileData[];
+    shape: number[];
+    dfName: string;
+}
+
 
 export type IDFProfileState = {
     lastUpdatedTime: number;
@@ -33,17 +35,65 @@ export type IDFProfileState = {
     warnings: Warning[]
 }
 
-export type IDFProfileData = {
-    profile: ColumnProfileData[];
-    shape: number[];
-    dfName: string;
-}
+export type IDFProfileWState = IDFProfileData & IDFProfileState
 
-export type IQuantChartData = {
-    binned_data: any[];
-    bin_size: number;
+// ~~~~~~~ General column type info ~~~~~~~
+export type IColMeta = {
+    numUnique: number;
+    nullCount: number;
 };
 
+export type ColumnProfileData = IColTypeTuple & {
+    nullCount: number,
+    summary: AnySummary;
+}
+
+export type AnySummary = NumericSummary | CategoricalSummary | BoolSummary | TemporalSummary;
+
+export type NumericSummary = {
+    summaryType: "numeric";
+    histogram: IHistogram;
+    quantMeta: IQuantMeta;
+}
+
+export type CategoricalSummary = { // string or boolean
+    summaryType: "categorical";
+    cardinality: number; // num unique
+    topK: ValueCount[];
+    stringMeta: IStringMeta;
+}
+
+export type BoolSummary = { // string or boolean
+    summaryType: "boolean";
+    cardinality: number; // num unique
+    topK: ValueCount[];
+}
+
+export type TemporalSummary = {
+    summaryType: "temporal";
+    histogram: IHistogram;
+    timeInterval: Interval;
+    temporalMeta: ITemporalMeta;
+}
+
+// type guards
+export function isNumericSummary(s: AnySummary): s is NumericSummary {
+    return (s as NumericSummary).summaryType === "numeric"
+}
+
+export function isCategoricalSummary(s: AnySummary): s is CategoricalSummary {
+    return (s as CategoricalSummary).summaryType === "categorical"
+}
+
+export function isBooleanSummary(s: AnySummary): s is BoolSummary {
+    return (s as BoolSummary).summaryType === "boolean"
+}
+
+export function isTemporalSummary(s: AnySummary): s is TemporalSummary {
+    return (s as TemporalSummary).summaryType === "temporal"
+}
+
+// ~~~~~~~ Individual data type info ~~~~~~~
 export type IQuantMeta = {
     min: number;
     q25: number;
@@ -59,11 +109,6 @@ export type IQuantMeta = {
     n_negative: number;
 };
 
-export type IColMeta = {
-    numUnique: number;
-    nullCount: number;
-};
-
 export type IStringMeta = {
     minLength: number;
     maxLength: number;
@@ -73,24 +118,6 @@ export type IStringMeta = {
 export type ITemporalMeta = {
     sortedness: string;
 }
-export type ColumnProfileData = {
-    name: string;
-    type: string;
-    isIndex: boolean;
-    summary: ColumnSummary;
-    nullCount: number;
-    example: any;
-};
-
-export interface ColumnSummary {
-    cardinality: number; // num unique
-    topK: ValueCount[];
-    histogram?: IHistogram;
-    timeInterval?: Interval;
-    quantMeta?: IQuantMeta;
-    stringMeta?: IStringMeta;
-    temporalMeta?: ITemporalMeta;
-}
 
 export type TimeBin = {
     count: number;
